SM3_MAX_MSG_BITLEN: int
SM3_DIGEST_LENGTH: int


class SM3:
    """SM3 Algorithm."""

    def __init__(self, data: bytes = b"") -> None:
        """SM3 Algorithm.

        Args:
            data: Initial data.
        """

    def update(self, data: bytes) -> None:
        """Update state.

        Args:
            data: Bytes data.
        """

    def digest(self) -> bytes:
        """Get digest.

        Returns:
            digest: Digest in bytes.
        """

    def reset(self) -> None:
        """Reset internal state."""

    def copy(self) -> SM3:
        """Copy a new SM3 object with identical state.

        Returns:
            sm3_obj: A new SM3 object.
        """



SM4_KEY_LENGTH: int
SM4_BLOCK_LENGTH: int


class SM4:
    def __init__(self, key: bytes) -> None:
        """SM4 Algorithm.

        Args:
            key: SM4 key.
        """

    def encrypt(self, block: bytes) -> bytes:
        """Encrypt.

        Args:
            block: Block data to be encrypted.

        Returns:
            cipher: Encrypted block data.
        """

    def decrypt(self, block: bytes) -> bytes:
        """Decrypt.

        Args:
            block: Block data to be decrypted.

        Returns:
            plain: Decrypted block data.
        """



from setuptools import Extension, setup

sm3_module = Extension(
    name="gmalglib.sm3",
    sources=[
        "src/gmalglib/sm3module.c",
        "src/gmalglib/sm3.c"
    ],
    include_dirs=[
        "include",
        "include/python3"
    ],
    depends=[
        "include/gmalglib/sm3.h"
    ]
)

sm4_module = Extension(
    name="gmalglib.sm4",
    sources=[
        "src/gmalglib/sm4module.c",
        "src/gmalglib/sm4.c"
    ],
    include_dirs=[
        "include",
        "include/python3"
    ],
    depends=[
        "include/gmalglib/sm4.h"
    ]
)

setup(
    ext_modules=[
        sm3_module,
        sm4_module,
    ]
)
